// --------------------------------------------------------------------
// Author  : mashimonator
// Create  : 2009/12/24
// Update  : 2009/12/24
// Description : 入力内容によってtextarea要素のサイズを自動調節する
// --------------------------------------------------------------------

/*@cc_on 
var doc = document;
eval('var document = doc');
@*/
var textareaAutoResize = {
	//-----------------------------------------
	// 設定値
	//-----------------------------------------
	config : {
		targetClass : 'autoResize', // 対象とするクラス名
		minRows : 2, // 最小値
		maxRows : 20, // 最大値
		brCode : '\n' // 改行コード
	},
	//-----------------------------------------
	// 初期処理
	//-----------------------------------------
	initialize : function() {
		var elements = textareaAutoResize.getTargetElements('textarea' ,textareaAutoResize.config.targetClass);
		for (var i = 0, len = elements.length; i < len; i++) {
			// minRowセット
			elements[i].minRow = textareaAutoResize.getRowsValue(elements[i]);
			// イベントセット
			if ( textareaAutoResize.isUnderIE7() ) {
				textareaAutoResize.addEvent(elements[i], 'keypress', textareaAutoResize.keypress);
			}
			textareaAutoResize.addEvent(elements[i], 'keydown', textareaAutoResize.keydown);
		}
	},
	//-----------------------------------------
	// keydown
	//-----------------------------------------
	keydown : function( event ) {
		if ( !event ) {
			event = window.event;
		}
		// Enter・BackSpace・Deleteキー押下の場合
		if ( event.keyCode == 13 ) {
			// 行追加
			textareaAutoResize.InsertRows(this);
		} else if ( event.keyCode == 8 || event.keyCode == 46 ) {
			// 行削除
			textareaAutoResize.deleteRows(this);
		}
	},
	//-----------------------------------------
	// keypress
	//-----------------------------------------
	keypress : function( event ) {
		if ( !event ) {
			event = window.event;
		}
		// Enterキー押下の場合
		if ( event.keyCode == 13 ) {
			// 行追加
			textareaAutoResize.InsertRows(this);
		}
	},
	//-----------------------------------------
	// リサイズ（行追加）
	//-----------------------------------------
	InsertRows : function( element ) {
		var bc = textareaAutoResize.getBreakCount(element.value);
		if ( (bc+1) > element.minRow ) {
			element.setAttribute('rows', bc+1);
		} else if ( (bc+1) <= element.minRow ) {
			element.setAttribute('rows', element.minRow);
		}
	},
	//-----------------------------------------
	// リサイズ（行削除）
	//-----------------------------------------
	deleteRows : function( element ) {
		var bc = textareaAutoResize.getBreakCount(element.value);
		if ( bc > element.minRow ) {
			element.setAttribute('rows', bc);
		} else if ( bc <= element.minRow ) {
			element.setAttribute('rows', element.minRow);
		}
	},
	//-----------------------------------------
	// 改行数を取得する
	//-----------------------------------------
	getBreakCount : function( str ) {
		var result = 1;
		if ( str && str != '' ) {
			var tmp = str.split(textareaAutoResize.config.brCode);
			if ( tmp.length > textareaAutoResize.config.maxRows ) {
				result = textareaAutoResize.config.maxRows;
			} else {
				result = tmp.length;
			}
		}
		return result;
	},
	//-----------------------------------------
	// デフォルト行数を取得する
	//-----------------------------------------
	getRowsValue : function( element ) {
		var rowCnt = element.getAttribute('rows');
		if ( rowCnt && rowCnt != '' && !isNaN(rowCnt) ) {
			return parseInt(rowCnt, 10);
		} else {
			return textareaAutoResize.config.minRows;
		}
	},
	//-----------------------------------------
	// IE7以下判定
	//-----------------------------------------
	isUnderIE7 : function() {
		IE='\v'=='v';
		if ( IE ) {
			if ( document.documentMode ) {
				if ( document.documentMode == '7' || document.documentMode == '5' ) {
					return true;
				} else {
					return false;
				}
			} else {
				return true;
			}
		} else {
			return false;
		}
	},
	//-----------------------------------------
	// ターゲットタグを取得する
	//-----------------------------------------
	getTargetElements : function( tag, cls ) {
		var elements = new Array();
		var targetElements = document.getElementsByTagName(tag.toUpperCase());
		for ( var i = 0, len = targetElements.length; i < len; i++ ) {
			if ( targetElements[i].className.match(cls) ) {
				elements[elements.length] = targetElements[i];
			}
		}
		return elements;
	},
	//-----------------------------------------
	// イベントに関数を付加する
	//-----------------------------------------
	addEvent : function( target, event, func ) {
		try {
			target.addEventListener(event, func, false);
		} catch (e) {
			target.attachEvent('on' + event, (function(el){return function(){func.call(el);};})(target));
		}
	}
}
// 実行
textareaAutoResize.addEvent( window, 'load', textareaAutoResize.initialize );